@@ -8,23 +8,41 @@
 
 RDF::Query::Node - Base class for RDF Nodes
 
+=head1 METHODS
+
+=over 4
+
 =cut
 
 package RDF::Query::Node;
 
 use strict;
 use warnings;
-
+no warnings 'redefine';
+use Scalar::Util qw(blessed);
 
 use RDF::Query::Node::Blank;
 use RDF::Query::Node::Literal;
 use RDF::Query::Node::Resource;
 use RDF::Query::Node::Variable;
 
+=item C<< is_variable >>
+
+Returns true if this RDF node is a variable, false otherwise.
+
+=cut
+
+sub is_variable {
+	my $self	= shift;
+	return (blessed($self) and $self->isa('RDF::Query::Node::Variable'));
+}
+
 1;
 
 __END__
 
+=back
+
 =head1 AUTHOR
 
  Gregory Todd Williams <gwilliams@cpan.org>
